# Technical debt log

[Technical debt](https://en.wikipedia.org/wiki/Technical_debt) is the consequence of poor design decisions, which may or may not be intentional. The consequences of this debt can include code being more difficult to extend, maintain or test.

Up to date documentation of technical debt can help to identify and prioritise improvements that will benefit ongoing development of the project.

## Technical debt

Technical debt log last updated: { current_date }

This project has incurred the following debt:

{ debt }
